import { and, eq, inArray } from 'drizzle-orm';
import { db } from '..';
import { brackets, type BracketInsert } from '../schema/brackets';

export async function insertBracket(competitionId: string, bracket: BracketInsert) {
	return await db.insert(brackets).values(bracket).returning();
}

export async function getBrackets(competitionId: string) {
	return await db.select().from(brackets).where(eq(brackets.competition_id, competitionId));
}

export async function getBracket(bracketId: string) {
	return await db.query.brackets.findFirst({
		where: eq(brackets.id, bracketId)
	});
}

export async function getBracketWithRoundsAndMatches(bracketId: string) {
	return await db.query.brackets.findFirst({
		where: eq(brackets.id, bracketId),
		with: {
			rounds: {
				with: {
					matches: {
						with: {
							team1: true,
							team2: true
						}
					}
				}
			}
		}
	});
}

export async function getBracketsWithRounds(competitionId: string) {
	return await db.query.brackets.findMany({
		where: eq(brackets.competition_id, competitionId),
		with: {
			rounds: true
		}
	});
}

export async function getBracketsByListIds(bracketIds: string[], withRelations: object = {}) {
	return await db.query.brackets.findMany({
		where: inArray(brackets.id, bracketIds),
		with: withRelations
	});
}
