import { eq } from 'drizzle-orm';
import { db } from '..';
import { competitions } from '../schema/competitions';

export async function getCompetition(id: string) {
	return await db.query.competitions.findFirst({
		where: eq(competitions.id, id)
	});
}

export async function getCompetitionWithAll(id: string) {
	return await db.query.competitions.findFirst({
		where: eq(competitions.id, id),
		with: {
			breakperiods: true,
			fields: true,
			brackets: {
				with: {
					rounds: {
						with: {
							matches: true
						}
					}
				}
			},
			teams: true
		}
	});
}

export async function getCompetitionsWithAll(skip: number = 0, take: number = 10) {
	return await db.query.competitions.findMany({
		orderBy: (competitions, { desc }) => [desc(competitions.start_date)],
		with: {
			breakperiods: true,
			fields: true,
			brackets: {
				with: {
					rounds: {
						with: {
							matches: true
						}
					}
				}
			},
			teams: true
		},
		limit: take,
		offset: skip
	});
}
