import { and, eq } from 'drizzle-orm';
import { db } from '..';
import { rounds, type RoundInsert } from '../schema/rounds';

export async function insertRound(round: RoundInsert) {
	return await db.insert(rounds).values(round).returning();
}

export async function getRounds(bracketId: string) {
	return await db.select().from(rounds).where(eq(rounds.bracket_id, bracketId));
}

export async function getRound(roundId: string) {
	return await db.select().from(rounds).where(eq(rounds.id, roundId));
}

export async function getRoundWithMatches(bracketId: string, roundId: string) {
	return await db.query.rounds.findMany({
		where: and(eq(rounds.bracket_id, bracketId), eq(rounds.id, roundId)),
		with: {
			matches: true
		}
	});
}
