import * as t from 'drizzle-orm/pg-core';
import { timestamps, type TModelWithRelations } from '../util';
import { competitions } from './competitions';
import { rounds, type RoundWithMatches } from './rounds';
import { relations } from 'drizzle-orm';
import { BracketType, enumToPgEnum, SchedulingMode } from '../../../../types';

export const bracketTypes = t.pgEnum('bracket_type', enumToPgEnum(BracketType));
export const schedulingModes = t.pgEnum('scheduling_modes', enumToPgEnum(SchedulingMode));

export const brackets = t.pgTable('brackets', {
	id: t.uuid('id').primaryKey().defaultRandom(),
	name: t.text('name').notNull(),
	bracketType: bracketTypes('bracket_type').notNull(),
	position: t.integer('position').default(1).notNull(),
	isActive: t.boolean('is_active').default(true).notNull(),
	scheduling_mode: schedulingModes('scheduling_modes').notNull(),
	competition_id: t.uuid('competition_id').notNull(),
	...timestamps
});

export const bracketsRelations = relations(brackets, ({ many, one }) => ({
	competition: one(competitions, {
		fields: [brackets.competition_id],
		references: [competitions.id],
		relationName: 'bracketCompetition'
	}),
	rounds: many(rounds)
}));

export type BracketInsert = typeof brackets.$inferInsert;
export type Bracket = TModelWithRelations<'brackets'>;
export type BracketWithRelations = TModelWithRelations<'brackets'>;
export type BracketAndRoundsWithMatches = typeof brackets.$inferSelect & {
	rounds: RoundWithMatches[];
};
