import * as t from 'drizzle-orm/pg-core';
import { timestamps } from '../util';
import { relations } from 'drizzle-orm';
import { competitions } from './competitions';
import { fields } from './fields';

export const breakperiodTypes = t.pgEnum('breakperiod_types', [
	'regular',
	'final',
	'extra',
	'gouter'
]);

export const breakperiods = t.pgTable('breakperiods', {
	id: t.uuid('id').primaryKey().defaultRandom(),
	competition_id: t.uuid('competition_id').notNull(),
	field_id: t.uuid('field_id').notNull(),
	type: breakperiodTypes('type').notNull(),
	round: t.integer('round').notNull(),
	start_date: t.timestamp({ withTimezone: true, mode: 'date' }).notNull(),
	end_date: t.timestamp({ withTimezone: true, mode: 'date' }).notNull(),
	...timestamps
});

export const breakperiodsRelations = relations(breakperiods, ({ one }) => ({
	competition: one(competitions, {
		fields: [breakperiods.competition_id],
		references: [competitions.id],
		relationName: 'breakPeriodCompetition'
	}),
	field: one(fields, {
		fields: [breakperiods.field_id],
		references: [fields.id],
		relationName: 'breakPeriodField'
	})
}));

export type Breakperiod = typeof breakperiods.$inferSelect;
