import * as t from 'drizzle-orm/pg-core';
import { timestamps, type TModelWithRelations } from '../util';
import { relations } from 'drizzle-orm';
import { users } from './users';
import { breakperiods } from './breakperiods';
import { fields } from './fields';
import { teams } from './teams';
import { brackets } from './brackets';

export const competitions = t.pgTable('competitions', {
	id: t.uuid('id').primaryKey().defaultRandom(),
	name: t.text('name').notNull(),
	description: t.text('description'),
	start_date: t.timestamp({ withTimezone: true, mode: 'date' }).notNull(),
	location: t.text('location'),
	owner: t.text('owner').notNull(),
	...timestamps
});

export const competitionsRelations = relations(competitions, ({ one, many }) => ({
	owner: one(users, {
		fields: [competitions.owner],
		references: [users.id],
		relationName: 'competitionOwner'
	}),
	breakperiods: many(breakperiods),
	fields: many(fields),
	teams: many(teams),
	brackets: many(brackets)
}));

export type Competition = typeof competitions.$inferSelect;

export type CompetitionWithRelations = TModelWithRelations<'competitions'>;
