import * as t from 'drizzle-orm/pg-core';
import { timestamps, type TModelWithRelations } from '../util';
import { relations } from 'drizzle-orm';
import { fields } from './fields';
import { rounds } from './rounds';
import { teams } from './teams';
import { brackets } from './brackets';
import { enumToPgEnum, MatchStatus } from '../../../../types';

export const status = t.pgEnum('match_status', enumToPgEnum(MatchStatus));

export const matches = t.pgTable('matches', {
	id: t.uuid('id').primaryKey().defaultRandom(),
	match_number: t.integer('match_number').notNull(),
	field_id: t.uuid('field_id').notNull(),
	team1_id: t.uuid('team1_id').notNull(),
	team2_id: t.uuid('team2_id').notNull(),
	winner_id: t.uuid('winner_id'),
	start_date: t.timestamp({ withTimezone: true, mode: 'date' }).notNull(),
	end_date: t.timestamp({ withTimezone: true, mode: 'date' }).notNull(),
	score1: t.integer('score1').notNull(),
	score2: t.integer('score2').notNull(),
	status: status('status').notNull(),
	position: t.integer('position').notNull(),
	table: t.integer('table').notNull(), // swis/round robin
	round_id: t.uuid('round_id').notNull(),
	bracket_id: t
		.uuid('bracket_id')
		.notNull()
		.references(() => brackets.id, { onDelete: 'cascade' }),
	...timestamps
});

export const matchRelations = relations(matches, ({ one }) => ({
	field: one(fields, {
		fields: [matches.field_id],
		references: [fields.id],
		relationName: 'matchField'
	}),
	round: one(rounds, {
		fields: [matches.round_id],
		references: [rounds.id],
		relationName: 'round'
	}),
	team1: one(teams, {
		fields: [matches.team1_id],
		references: [teams.id],
		relationName: 'matchTeam1'
	}),
	team2: one(teams, {
		fields: [matches.team2_id],
		references: [teams.id],
		relationName: 'matchTeam2'
	}),
	winner: one(teams, {
		fields: [matches.winner_id],
		references: [teams.id],
		relationName: 'matchWinner'
	}),
	bracket: one(brackets, {
		fields: [matches.bracket_id],
		references: [brackets.id],
		relationName: 'matchBracket'
	})
}));

export type Match = typeof matches.$inferSelect;

export type MatchWithRelations = TModelWithRelations<'matches'>;
