import { relations } from 'drizzle-orm';
import * as t from 'drizzle-orm/pg-core';
import { matches } from './matches';
import { timestamps, type TModelWithRelations } from '../util';
import { brackets } from './brackets';

export const rounds = t.pgTable('rounds', {
	id: t.uuid('id').primaryKey().defaultRandom(),
	name: t.text('name').notNull(),
	round_number: t.integer('round_number').notNull(),
	nb_matches: t.integer('nb_matches').notNull(),
	bracket_id: t.uuid('bracket_id').references(() => brackets.id, { onDelete: 'cascade' }),
	...timestamps
});

export const roundsRelations = relations(rounds, ({ many, one }) => ({
	matches: many(matches),
	bracket: one(brackets, {
		fields: [rounds.bracket_id],
		references: [brackets.id],
		relationName: 'bracket'
	})
}));

export type Round = typeof rounds.$inferSelect;

export type RoundInsert = typeof rounds.$inferInsert;

export type RoundWithRelations = TModelWithRelations<'rounds'>;

export type RoundWithMatches = typeof rounds.$inferSelect & {
	matches: (typeof matches.$inferSelect)[];
};
