import { relations } from 'drizzle-orm';
import * as t from 'drizzle-orm/pg-core';
import { roles } from './roles';
import { permissions } from './permissions';
import { users } from './users';
import { timestamps } from '../util';

export const permissionsToRoles = t.pgTable(
	'permissions_to_roles',
	{
		permission_id: t
			.uuid('permission_id')
			.notNull()
			.references(() => permissions.id),
		role_id: t
			.uuid('role_id')
			.notNull()
			.references(() => roles.id),
		granted: t.boolean('granted').notNull(),
		...timestamps
	},
	(table) => [t.primaryKey({ columns: [table.permission_id, table.role_id] })]
);

export const permissionsToRolesRelations = relations(permissionsToRoles, ({ one }) => ({
	permission: one(permissions, {
		fields: [permissionsToRoles.permission_id],
		references: [permissions.id],
		relationName: 'permissionRole'
	}),
	role: one(roles, {
		fields: [permissionsToRoles.role_id],
		references: [roles.id],
		relationName: 'rolePermission'
	})
}));

export const usersToRoles = t.pgTable(
	'users_to_roles',
	{
		user_id: t
			.uuid('user_id')
			.notNull()
			.references(() => users.id),
		role_id: t
			.uuid('role_id')
			.notNull()
			.references(() => roles.id),
		granted: t.boolean('granted').notNull(),
		...timestamps
	},
	(table) => [t.primaryKey({ columns: [table.user_id, table.role_id] })]
);

export const usersToRolesRelations = relations(usersToRoles, ({ one }) => ({
	user: one(users, {
		fields: [usersToRoles.user_id],
		references: [users.id],
		relationName: 'userRole'
	}),
	role: one(roles, {
		fields: [usersToRoles.role_id],
		references: [roles.id],
		relationName: 'roleUser'
	})
}));

export const usersToPermissions = t.pgTable(
	'users_to_permissions',
	{
		user_id: t
			.uuid('user_id')
			.notNull()
			.references(() => users.id),
		permission_id: t
			.uuid('permission_id')
			.notNull()
			.references(() => permissions.id),
		granted: t.boolean('granted').notNull(),
		...timestamps
	},
	(table) => [t.primaryKey({ columns: [table.user_id, table.permission_id] })]
);

export const usersToPermissionsRelations = relations(usersToPermissions, ({ one }) => ({
	user: one(users, {
		fields: [usersToPermissions.user_id],
		references: [users.id],
		relationName: 'userPermission'
	}),
	permission: one(permissions, {
		fields: [usersToPermissions.permission_id],
		references: [permissions.id],
		relationName: 'permissionUser'
	})
}));
