import { SingleEliminationGenerator } from './single-elimination';
import { DoubleEliminationGenerator } from './double-elimination';
import { SwissGenerator } from './swiss';
import { RoundRobinGenerator } from './round-robin';
import { DoubleRoundRobinGenerator } from './double-round-robin';
import { SchedulingMode } from '../../../types';
import type { TournamentGenerator } from './types';

/**
 * Factory function to create the appropriate tournament generator based on the scheduling mode
 */
export function createTournamentGenerator(
	mode: SchedulingMode,
	competitionId: string,
	teamsCount: number
): TournamentGenerator {
	switch (mode) {
		case SchedulingMode.single:
			return new SingleEliminationGenerator(competitionId, teamsCount);
		case SchedulingMode.double:
			return new DoubleEliminationGenerator(competitionId, teamsCount);
		case SchedulingMode.swiss:
			return new SwissGenerator(competitionId, teamsCount);
		case SchedulingMode.round_robin:
			return new RoundRobinGenerator(competitionId, teamsCount);
		case SchedulingMode.double_round_robin:
			return new DoubleRoundRobinGenerator(competitionId, teamsCount);
		default:
			throw new Error(`Unsupported scheduling mode: ${mode}`);
	}
}

export * from './types';
